@@ -20,6 +20,8 @@ ch.setFormatter(formatter)
 logger.addHandler(ch)
 logger.setLevel(logging.WARNING)
 
+mongo_addr = load_setting().mongo_addr
+
 
 def chk_deactivate_mongo(func):
     """
@@ -27,8 +29,7 @@ def chk_deactivate_mongo(func):
     데코레이션을 통해 해당 함수를 사용하지 못하도록 하는 데코함수
     """
     def wrapper(*args, **kwargs):
-        addr = load_setting()['mongo']
-        if addr == '' or addr is None:
+        if not load_setting().active_mongo:
             print('mongo db is deactivated..')
             return None
         else:
@@ -38,10 +39,10 @@ def chk_deactivate_mongo(func):
 
 class Base:
     def __init__(self, db, col):
-        self.mongo_addr = load_setting()['mongo']
+        self.mongo_addr = load_setting().mongo_addr
 
         # mongodb 에 연결
-        if self.mongo_addr != '':
+        if load_setting().active_mongo:
             self.client = pymongo.MongoClient(self.mongo_addr)
             self.db = db
             self.col = col
@@ -89,13 +90,13 @@ class Base:
     @staticmethod
     @chk_deactivate_mongo
     def get_all_db() -> list:
-        client = pymongo.MongoClient(load_setting()['mongo'])
+        client = pymongo.MongoClient(mongo_addr)
         return sorted(client.list_database_names())
 
     @staticmethod
     @chk_deactivate_mongo
     def drop_all_db():
-        client = pymongo.MongoClient(load_setting()['mongo'])
+        client = pymongo.MongoClient(mongo_addr)
         pre_db = Base.get_all_db()
         for db in pre_db:
             client.drop_database(db)
@@ -105,7 +106,7 @@ class Base:
     @staticmethod
     @chk_deactivate_mongo
     def drop_db(db: str):
-        client = pymongo.MongoClient(load_setting()['mongo'])
+        client = pymongo.MongoClient(mongo_addr)
         pre_db = Base.get_all_db()
         if db in pre_db:
             client.drop_database(db)
@@ -336,7 +337,7 @@ class Corps(Base):
 
     @staticmethod
     def drop_all_corps():
-        client = pymongo.MongoClient(load_setting()['mongo'])
+        client = pymongo.MongoClient(mongo_addr)
         pre_db = Corps.get_all_corps()
         for db in pre_db:
             client.drop_database(db)
@@ -628,8 +629,8 @@ class C106(Corps):
 
         c106컬렉션에서 title이 c106y 또는 c106q가 아닌 도큐먼트가 저장되어 있으면 찾아내서 삭제함.
         """
-        client = pymongo.MongoClient(load_setting()['mongo'])
-        print(f"Mongo addr: {load_setting()['mongo']}")
+        client = pymongo.MongoClient(mongo_addr)
+        print(f"Mongo addr: {mongo_addr}")
         for i, db in enumerate(Corps.get_all_corps()):
             print(f'{i+1}. Cleaning c106 collection in {db} db.')
             try:
@@ -772,7 +773,7 @@ class C1034(Corps):
     def get_stamp(self) -> datetime.datetime:
         return self.client[self.db][self.col].find({'stamp': {'$exists': True}}).next()['stamp']
 
-    def find_cmp(self, title:str) -> float:
+    def find_cmp(self, title: str) -> float:
         """
 
         타이틀에 해당하는 전년/분기대비 값을 반환한다.\n
