@@ -19,6 +19,10 @@ FULL_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), FILENAME)
 
 
 class DbSetting:
+    """데이터베이스 설정 데이터
+
+    데이터베이스의 경로와 활성화 여부를 저장하는 클래스로 피클에 저장되어 사용됨
+    """
     def __init__(self):
         self.mongo_addr = DEF_MONGO_ADDR
         self.active_mongo = True
@@ -34,8 +38,12 @@ class DbSetting:
         s = ''
         if self.active_mongo:
             s += f'Mongo db(active) : {self.mongo_addr}\n'
+        else:
+            s += f'Mongo db(inactive) : {self.mongo_addr}\n'
         if self.active_sqlite3:
-            s += f'Sqlite3 db(active) : {self.sqlite3_path}\n'
+            s += f'Sqlite3 db(active) : {self.sqlite3_path}'
+        else:
+            s += f'Sqlite3 db(inactive) : {self.sqlite3_path}'
         return s
 
 
@@ -56,6 +64,10 @@ def load() -> DbSetting:
 
 
 def chg_mongo_addr(addr: str):
+    """몽고 db의 주소 변경
+
+    몽고 db의 주소를 변경하는 함수로 형식을 검사하여 적합하면 변경함.
+    """
     if addr.startswith('mongodb://'):
         s = load()
         before = s.mongo_addr
